//// [MemberFunctionDeclaration2_es6.ts]
class C {
   public * foo() { }
}

//// [MemberFunctionDeclaration2_es6.js]
class C {
    *foo() { }
}
